==> jc-1.4.0.tar.gz: gnu/java/awt/color/ColorLookUpTable.h <==
// public class gnu.java.awt.color.ColorLookUpTable

// class file dependencies
// @dep_class a1be72e974cebf6b gnu_java_awt_color_ColorLookUpTable
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_ColorLookUpTable_H_
#define _JC_gnu_java_awt_color_ColorLookUpTable_H_

// Forward structure declarations
struct _jc_java_awt_color_ICC__5fProfile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_refs	_jc_gnu_java_awt_color_ColorLookUpTable$sub_refs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs	_jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$refs	_jc_gnu_java_awt_color_ColorLookUpTable$refs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$nonrefs	_jc_gnu_java_awt_color_ColorLookUpTable$nonrefs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$object	_jc_gnu_java_awt_color_ColorLookUpTable$object;

typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$fields_struct	_jc_gnu_java_awt_color_ColorLookUpTable$fields_struct;
typedef const struct _jc_gnu_java_awt_color_ColorLookUpTable$vmethods	_jc_gnu_java_awt_color_ColorLookUpTable$vmethods;
typedef const struct _jc_gnu_java_awt_color_ColorLookUpTable$vtable	_jc_gnu_java_awt_color_ColorLookUpTable$vtable;
typedef const struct _jc_gnu_java_awt_color_ColorLookUpTable$vtype	_jc_gnu_java_awt_color_ColorLookUpTable$vtype;

// Class fields structure
struct _jc_gnu_java_awt_color_ColorLookUpTable$fields_struct {
	_jc_float_array	*D50;
};
extern _jc_gnu_java_awt_color_ColorLookUpTable$fields_struct _jc_gnu_java_awt_color_ColorLookUpTable$class_fields;

// Constructors
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$_init$531e5016187d129e(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_java_awt_color_ICC__5fProfile$object *, jint);

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_ColorLookUpTable$method$LabtoXYZ$b6efffb3715ce3a7(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_ColorLookUpTable$method$XYZtoLab$f744f18effb96555(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_ColorLookUpTable$method$lookup$a113f7be151213b9(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *);
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$readClut16$6ad927ab2e040081(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$readClut8$18123c49721016fc(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$LabtoXYZ$b6efffb3715ce3a7;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$XYZtoLab$f744f18effb96555;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$lookup$a113f7be151213b9;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$readClut16$6ad927ab2e040081;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$readClut8$18123c49721016fc;

// Static methods
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_awt_color_ColorLookUpTable$vmethods {
	_jc_float_array	*(*LabtoXYZ$b6efffb3715ce3a7)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *);
	_jc_float_array	*(*XYZtoLab$f744f18effb96555)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *);
	_jc_float_array	*(*lookup$a113f7be151213b9)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *);
	void	(*readClut16$6ad927ab2e040081)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *);
	void	(*readClut8$18123c49721016fc)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *);
};

// Vtable
struct _jc_gnu_java_awt_color_ColorLookUpTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_ColorLookUpTable$vmethods	gnu_java_awt_color_ColorLookUpTable;
};

// Vtype
struct _jc_gnu_java_awt_color_ColorLookUpTable$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_ColorLookUpTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_refs {
	_jc_object_array	*inTable;
	_jc_object_array	*outTable;
	_jc_double_array	*clut;
	_jc_object_array	*inMatrix;
	_jc_int_array	*multiplier;
	_jc_int_array	*offsets;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_ColorLookUpTable$refs {
    _jc_gnu_java_awt_color_ColorLookUpTable$sub_refs	gnu_java_awt_color_ColorLookUpTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs {
	jint	nIn;
	jint	nOut;
	jint	nInTableEntries;
	jint	nOutTableEntries;
	jint	gridpoints;
	jint	nClut;
	jboolean	useMatrix;
	jboolean	inputLab;
	jboolean	outputLab;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_ColorLookUpTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs	gnu_java_awt_color_ColorLookUpTable;
};

// Object instance structure
struct _jc_gnu_java_awt_color_ColorLookUpTable$object {
	_jc_gnu_java_awt_color_ColorLookUpTable$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_ColorLookUpTable$vtype	*vtype;
	_jc_gnu_java_awt_color_ColorLookUpTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_ColorLookUpTable$vtype _jc_gnu_java_awt_color_ColorLookUpTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_ColorLookUpTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_ColorLookUpTable$class_object;

#endif	/* _JC_gnu_java_awt_color_ColorLookUpTable_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/ColorLookUpTable.h <==
// public class gnu.java.awt.color.ColorLookUpTable

// class file dependencies
// @dep_class f2d1a85fa7f62703 gnu_java_awt_color_ColorLookUpTable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_ColorLookUpTable_H_
#define _JC_gnu_java_awt_color_ColorLookUpTable_H_

// Forward structure declarations
struct _jc_java_awt_color_ICC__5fProfile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_refs	_jc_gnu_java_awt_color_ColorLookUpTable$sub_refs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs	_jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$refs	_jc_gnu_java_awt_color_ColorLookUpTable$refs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$nonrefs	_jc_gnu_java_awt_color_ColorLookUpTable$nonrefs;
typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$object	_jc_gnu_java_awt_color_ColorLookUpTable$object;

typedef struct _jc_gnu_java_awt_color_ColorLookUpTable$fields_struct	_jc_gnu_java_awt_color_ColorLookUpTable$fields_struct;
typedef const struct _jc_gnu_java_awt_color_ColorLookUpTable$vmethods	_jc_gnu_java_awt_color_ColorLookUpTable$vmethods;
typedef const struct _jc_gnu_java_awt_color_ColorLookUpTable$vtable	_jc_gnu_java_awt_color_ColorLookUpTable$vtable;
typedef const struct _jc_gnu_java_awt_color_ColorLookUpTable$vtype	_jc_gnu_java_awt_color_ColorLookUpTable$vtype;

// Class fields structure
struct _jc_gnu_java_awt_color_ColorLookUpTable$fields_struct {
	_jc_float_array	*D50;
};
extern _jc_gnu_java_awt_color_ColorLookUpTable$fields_struct _jc_gnu_java_awt_color_ColorLookUpTable$class_fields;

// Constructors
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$_init$531e5016187d129e(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_java_awt_color_ICC__5fProfile$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_ColorLookUpTable$method$LabtoXYZ$b6efffb3715ce3a7(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_ColorLookUpTable$method$XYZtoLab$f744f18effb96555(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_ColorLookUpTable$method$lookup$a113f7be151213b9(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$readClut16$6ad927ab2e040081(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$readClut8$18123c49721016fc(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$LabtoXYZ$b6efffb3715ce3a7;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$XYZtoLab$f744f18effb96555;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$lookup$a113f7be151213b9;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$readClut16$6ad927ab2e040081;
extern _jc_method _jc_gnu_java_awt_color_ColorLookUpTable$method_info$readClut8$18123c49721016fc;

// Static methods
extern void _jc_gnu_java_awt_color_ColorLookUpTable$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_color_ColorLookUpTable$vmethods {
	_jc_float_array	*(*LabtoXYZ$b6efffb3715ce3a7)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*XYZtoLab$f744f18effb96555)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*lookup$a113f7be151213b9)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	void	(*readClut16$6ad927ab2e040081)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*readClut8$18123c49721016fc)(_jc_env *, struct _jc_gnu_java_awt_color_ColorLookUpTable$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_ColorLookUpTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_ColorLookUpTable$vmethods	gnu_java_awt_color_ColorLookUpTable;
};

// Vtype
struct _jc_gnu_java_awt_color_ColorLookUpTable$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_ColorLookUpTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_refs {
	_jc_object_array	*inTable;
	_jc_object_array	*outTable;
	_jc_double_array	*clut;
	_jc_object_array	*inMatrix;
	_jc_int_array	*multiplier;
	_jc_int_array	*offsets;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_ColorLookUpTable$refs {
    _jc_gnu_java_awt_color_ColorLookUpTable$sub_refs	gnu_java_awt_color_ColorLookUpTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs {
	jint	nIn;
	jint	nOut;
	jint	nInTableEntries;
	jint	nOutTableEntries;
	jint	gridpoints;
	jint	nClut;
	jboolean	useMatrix;
	jboolean	inputLab;
	jboolean	outputLab;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_ColorLookUpTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_ColorLookUpTable$sub_nonrefs	gnu_java_awt_color_ColorLookUpTable;
};

// Object instance structure
struct _jc_gnu_java_awt_color_ColorLookUpTable$object {
	_jc_gnu_java_awt_color_ColorLookUpTable$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_ColorLookUpTable$vtype	*vtype;
	_jc_gnu_java_awt_color_ColorLookUpTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_ColorLookUpTable$vtype _jc_gnu_java_awt_color_ColorLookUpTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_ColorLookUpTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_ColorLookUpTable$class_object;

#endif	/* _JC_gnu_java_awt_color_ColorLookUpTable_H_ */
